from pydantic import BaseModel, Field

from xmpp_api.db.bot import JIDType


class BotInformation(BaseModel):
    # The bot's ID
    id: str

    # The bot's name
    name: str

    # The bot's localpart
    localpart: str

    # The bot's description
    description: str | None

    # List of constraints on the bot
    constraints: list["BotConstraint"]


class AllowedJidInformation(BaseModel):
    jid: str

    token: str


class BotConstraint(BaseModel): ...


class BotDomainConstraint(BotConstraint):
    domains: list[str]


class CreateBotRequest(BaseModel):
    # The bot's name
    name: str

    # The bot's description
    description: str | None = Field(default=None)

    # List of constraints
    constraints: list[BotConstraint] = Field(default_factory=list)

    # The localpart of the bot
    localpart: str


class BotCreationResponse(BotInformation):
    # The bot's token
    token: str


class AddJidRequest(BaseModel):
    # The JID that the message will be sent to
    jid: str

    # The JID type. If set, then we will not discover it automatically
    type: JIDType | None = Field(default=None)


class AddJidResponse(BaseModel):
    token: str


class SendMessageRequest(BaseModel):
    # The message content
    body: str


class GetBotInformation(BotInformation):
    jids: list[AllowedJidInformation]
